# 安全政策

## 支持的版本

| 版本 | 是否支持 |
| ------- | ------------------ |
| 3.x.x   | :white_check_mark: |
| < 3.x   | :x:                |

## 报告漏洞

请通过以下方法之一（按优先顺序）报告任何漏洞：

在本仓库内报告漏洞。来自 GitHub 的这套工作流允许用户以私密且安全的方式报告漏洞。

通过电子邮件联系 contact@meloland.org 报告。

# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 3.x.x   | :white_check_mark: |
| < 3.x   | :x:                |

## Reporting a Vulnerability

Please report any vulnerabilities via one of the following methods (in order of preference):

Report a vulnerability within this repository. The Github workflow allows user to report vulnerabilities in a private manner and securely.

Report via email to contact@meloland.org.
